Bridgic Core
============

The core Python package of the Bridgic Library. It provides essential classes and abstractions that form the foundation for building LLM applications, such as agents, workflows, and more. We carefully designed the core library so that developers could writting their programs using "worker" and "automa" expressions. 

By installing the core package via ```pip install bridgic-core```, you can introduce flexible, convenient, and concise process orchestration capabilities to your program with minimal dependencies.